%=========================================================================%
% Roberto Pancrazi, University of Warwick
% Hernan Seoane, UC3
% Marija Vukotic, Univerisity of Warwick

%=========================================================================%
% In case you use this code please cite the paper:

% Pancrazi R., Seoane H., Vukotic M., 2016, "The Price of Capital and the Financial Accellerator".

%=========================================================================%
%         Code that reproduces the IRFs in Figure 1 and Figure 2 of the paper: 
%    Pancrazi R., Seoane H., Vukotic M., 2016, "The Price of Capital and
%    the Financial Accellerator".
%=========================================================================%

%=========================================================================%

%% READ ME:

% First, run the mod file BGG99.mod and BGG99_delay.mod with Dynare
% Then, run the mod file BGG99_qtilde.mod and BGG99_delay_qtilde.mod with Dynare
% Then, run this file.



%%
clear all
clc
close all

%% CHOOSE WHICH MODEL TO RUN: 
% DELAY = 0; Plot IRF for the benchmark model
% DELAY = 1; Plot IRF for the investment delay model

DELAY =0; 


if DELAY==0
     load('BGG99_results.mat')
     oo_ORIG=oo_;
     load('BGG99_qtilde_results.mat')
    
elseif DELAY==1
    load('BGG99_delay_results.mat')
    oo_ORIG=oo_;
    load('BGG99_delay_qtilde_results.mat')
end

%%
figure (1)
subplot(441)
plot(oo_.irfs.y_eM)
hold on
plot(oo_ORIG.irfs.y_eM)
hold off
legend('Correct q_tilde','BGG')
title('output to monetary')
subplot(442)
plot(oo_.irfs.c_eM)
hold on
plot(oo_ORIG.irfs.c_eM)
hold off
legend('Correct q_tilde','BGG')
title('consumption to monetary')
subplot(443)
plot(oo_.irfs.i_eM)
hold on
plot(oo_ORIG.irfs.i_eM)
hold off
legend('our','original')
title('investment to monetary')
subplot(444)
plot(oo_.irfs.g_eM)
hold on
plot(oo_ORIG.irfs.g_eM)
hold off
legend('Correct q_tilde','BGG')
title('goverment spending to monetary')
subplot(445)
plot(oo_.irfs.ce_eM)
hold on
plot(oo_ORIG.irfs.ce_eM)
hold off
legend('Correct q_tilde','BGG')
title('consumption enterpr to monetary')
subplot(446)
plot(oo_.irfs.n_eM)
hold on
plot(oo_ORIG.irfs.n_eM)
hold off
legend('Correct q_tilde','BGG')
title('net worth to monetary')
subplot(447)
plot(oo_.irfs.rk_eM-oo_.irfs.r_eM)
hold on
plot(oo_ORIG.irfs.rk_eM-oo_ORIG.irfs.r_eM)
hold off
legend('Correct q_tilde','BGG')
title('Spread(rk-r) to monetary')
subplot(448)
plot(oo_.irfs.r_eM)
hold on
plot(oo_ORIG.irfs.r_eM)
hold off
legend('Correct q_tilde','BGG')
title('real rate to monetary')
subplot(449)
plot(oo_.irfs.q_eM)
hold on
plot(oo_ORIG.irfs.q_eM)
hold off
legend('Correct q_tilde','BGG')
title('q to monetary')

subplot(4,4,10)
plot(oo_.irfs.qtilde_eM)
hold on
%plot(oo_ORIG.irfs.qtilde_eM)
hold off
%legend('Correct q_tilde','BGG')
legend('Correct q_tilde')
title('qtilde to monetary')

subplot(4,4,11)
plot(oo_.irfs.k_eM)
hold on
plot(oo_ORIG.irfs.k_eM)
hold off
legend('Correct q_tilde','BGG')
title('capital to monetary')

subplot(4,4,12)
plot(oo_.irfs.x_eM)
hold on
plot(oo_ORIG.irfs.x_eM)
hold off
legend('Correct q_tilde','BGG')
title('markup to monetary')

subplot(4,4,13)
plot(oo_.irfs.a_eM)
hold on
plot(oo_ORIG.irfs.a_eM)
hold off
legend('Correct q_tilde','BGG')
title('technologhy to monetary')

subplot(4,4,14)
plot(oo_.irfs.h_eM)
hold on
plot(oo_ORIG.irfs.h_eM)
hold off
legend('Correct q_tilde','BGG')
title('labor to monetary')

subplot(4,4,15)
plot(oo_.irfs.pi_eM)
hold on
plot(oo_ORIG.irfs.pi_eM)
hold off
legend('Correct q_tilde','BGG')
title('inflation to monetary')

subplot(4,4,16)
plot(oo_.irfs.rn_eM)
hold on
plot(oo_ORIG.irfs.rn_eM)
hold off
legend('Correct q_tilde','BGG')
title('nominal rate to monetary')


%% 
figure (2)
subplot(441)
plot(oo_.irfs.y_eA)
hold on
plot(oo_ORIG.irfs.y_eA)
hold off
legend('Correct q_tilde','BGG')
title('output to technology')
subplot(442)
plot(oo_.irfs.c_eA)
hold on
plot(oo_ORIG.irfs.c_eA)
hold off
legend('Correct q_tilde','BGG')
title('consumption to technology')
subplot(443)
plot(oo_.irfs.i_eA)
hold on
plot(oo_ORIG.irfs.i_eA)
hold off
legend('Correct q_tilde','BGG')
title('investment to technology')
subplot(444)
plot(oo_.irfs.g_eA)
hold on
plot(oo_ORIG.irfs.g_eA)
hold off
legend('Correct q_tilde','BGG')
title('goverment spending to technology')
subplot(445)
plot(oo_.irfs.ce_eA)
hold on
plot(oo_ORIG.irfs.ce_eA)
hold off
legend('Correct q_tilde','BGG')
title('consumption enterpr to technology')
subplot(446)
plot(oo_.irfs.n_eA)
hold on
plot(oo_ORIG.irfs.n_eA)
hold off
legend('Correct q_tilde','BGG')
title('net worth to technology')
subplot(447)
plot(oo_.irfs.rk_eA-oo_.irfs.r_eA)
hold on
plot(oo_ORIG.irfs.rk_eA-oo_ORIG.irfs.r_eA)
hold off
legend('Correct q_tilde','BGG')
title('Spread(rk-r) to technology')
subplot(448)
plot(oo_.irfs.r_eA)
hold on
plot(oo_ORIG.irfs.r_eA)
hold off
legend('Correct q_tilde','BGG')
title('real rate to technology')
subplot(449)
plot(oo_.irfs.q_eA)
hold on
plot(oo_ORIG.irfs.q_eA)
hold off
legend('Correct q_tilde','BGG')
title('q to technology')

subplot(4,4,10)
plot(oo_.irfs.qtilde_eA)
hold on
%plot(oo_ORIG.irfs.qtilde_eA)
hold off
%legend('Correct q_tilde','BGG')
legend('Correct q_tilde')
title('qtilde to technology')

subplot(4,4,11)
plot(oo_.irfs.k_eA)
hold on
plot(oo_ORIG.irfs.k_eA)
hold off
legend('Correct q_tilde','BGG')
title('capital to technology')

subplot(4,4,12)
plot(oo_.irfs.x_eA)
hold on
plot(oo_ORIG.irfs.x_eA)
hold off
legend('Correct q_tilde','BGG')
title('markup to technology')

subplot(4,4,13)
plot(oo_.irfs.a_eA)
hold on
plot(oo_ORIG.irfs.a_eA)
hold off
legend('Correct q_tilde','BGG')
title('technologhy to technology')

subplot(4,4,14)
plot(oo_.irfs.h_eA)
hold on
plot(oo_ORIG.irfs.h_eA)
hold off
legend('Correct q_tilde','BGG')
title('labor to technology')

subplot(4,4,15)
plot(oo_.irfs.pi_eA)
hold on
plot(oo_ORIG.irfs.pi_eA)
hold off
legend('Correct q_tilde','BGG')
title('inflation to technology')

subplot(4,4,16)
plot(oo_.irfs.rn_eA)
hold on
plot(oo_ORIG.irfs.rn_eA)
hold off
legend('Correct q_tilde','BGG')
title('nominal rate to technology')

%%
figure (3)
subplot(441)
plot(oo_.irfs.y_eG)
hold on
plot(oo_ORIG.irfs.y_eG)
hold off
legend('Correct q_tilde','BGG')
title('output to govt spend')
subplot(442)
plot(oo_.irfs.c_eG)
hold on
plot(oo_ORIG.irfs.c_eG)
hold off
legend('Correct q_tilde','BGG')
title('consumption to govt spend')
subplot(443)
plot(oo_.irfs.i_eG)
hold on
plot(oo_ORIG.irfs.i_eG)
hold off
legend('Correct q_tilde','BGG')
title('investment to govt spend')
subplot(444)
plot(oo_.irfs.g_eG)
hold on
plot(oo_ORIG.irfs.g_eG)
hold off
legend('Correct q_tilde','BGG')
title('goverment spending to govt spend')
subplot(445)
plot(oo_.irfs.ce_eG)
hold on
plot(oo_ORIG.irfs.ce_eG)
hold off
legend('Correct q_tilde','BGG')
title('consumption enterpr to govt spend')
subplot(446)
plot(oo_.irfs.n_eG)
hold on
plot(oo_ORIG.irfs.n_eG)
hold off
legend('Correct q_tilde','BGG')
title('net worth to govt spend')
subplot(447)
plot(oo_.irfs.rk_eG-oo_.irfs.r_eG)
hold on
plot(oo_ORIG.irfs.rk_eG-oo_ORIG.irfs.r_eG)
hold off
legend('Correct q_tilde','BGG')
title('Spread(rk-r) to govt spend')
subplot(448)
plot(oo_.irfs.r_eG)
hold on
plot(oo_ORIG.irfs.r_eG)
hold off
legend('Correct q_tilde','BGG')
title('reGl rate to govt spend')
subplot(449)
plot(oo_.irfs.q_eG)
hold on
plot(oo_ORIG.irfs.q_eG)
hold off
legend('Correct q_tilde','BGG')
title('q to govt spend')

subplot(4,4,10)
plot(oo_.irfs.qtilde_eG)
hold on
%plot(oo_ORIG.irfs.qtilde_eG)
hold off
%legend('Correct q_tilde','BGG')
legend('Correct q_tilde')
title('qtilde to govt spend')

subplot(4,4,11)
plot(oo_.irfs.k_eG)
hold on
plot(oo_ORIG.irfs.k_eG)
hold off
legend('Correct q_tilde','BGG')
title('capital to govt spend')

subplot(4,4,12)
plot(oo_.irfs.x_eG)
hold on
plot(oo_ORIG.irfs.x_eG)
hold off
legend('Correct q_tilde','BGG')
title('markup to govt spend')

subplot(4,4,13)
plot(oo_.irfs.a_eG)
hold on
plot(oo_ORIG.irfs.a_eG)
hold off
legend('Correct q_tilde','BGG')
title('technologhy to govt spend')

subplot(4,4,14)
plot(oo_.irfs.h_eG)
hold on
plot(oo_ORIG.irfs.h_eG)
hold off
legend('Correct q_tilde','BGG')
title('labor to govt spend')

subplot(4,4,15)
plot(oo_.irfs.pi_eG)
hold on
plot(oo_ORIG.irfs.pi_eG)
hold off
legend('Correct q_tilde','BGG')
title('inflation to govt spend')

subplot(4,4,16)
plot(oo_.irfs.rn_eG)
hold on
plot(oo_ORIG.irfs.rn_eG)
hold off
legend('Correct q_tilde','BGG')
title('nominal rate to govt spend')

%% COMPUTE THE STANDARD DEVIATION OF THE MODELS to replicate Table 1 

std_OUR     =   diag((oo_.var).^(1/2));
std_ORIG    =   diag((oo_ORIG.var).^(1/2));

autocorr_OUR     =   diag((oo_.autocorr{1,1}));
autocorr_ORIG    =   diag((oo_ORIG.autocorr{1,1}));

if DELAY==0
    load('BGG99_results.mat')
TABLE_std = [M_.endo_names num2str(std_OUR(1:end-1)) num2str(std_ORIG)];
TABLE_autocorr = [M_.endo_names num2str(autocorr_OUR(1:end-1)) num2str(autocorr_ORIG)];
elseif DELAY==1
        load('BGG99_delay_results.mat')
TABLE_std = [M_.endo_names num2str(std_OUR(1:end-1)) num2str(std_ORIG)];
TABLE_autocorr = [M_.endo_names num2str(autocorr_OUR(1:end-1)) num2str(autocorr_ORIG)];
end
    
TABLE_std
